@@ -1,53 +1,53 @@
-import pywrapper_fmtools as pyw
+import pyfmtools as pyfm
 import sys
 
 r=3
 n=3
-env = pyw.fm_init( n)
-pyw.isTest = True
+env = pyfm.fm_init( n)
+pyfm.isTest = True
 
-A = pyw.ShowCoalitions( env)
+A = pyfm.ShowCoalitions( env)
 print( "Fuzzy measure wrt n=3 criteria has ",env.m," parameters ordered like this (binary order)")
 print( A)
-pyw.fm_free( env);
+pyfm.fm_free( env);
 
 ti=1
 n=4
-env = pyw.fm_init( n)
-size, v = pyw.generate_fm_2additive_concave( ti,n, env)
+env = pyfm.fm_init( n)
+size, v = pyfm.generate_fm_2additive_concave( ti,n, env)
 print( "2-additive concave FM in Mobius and its length (n=4)")
 print( v)
 print("has ", size, " nonzero parameters ")
 
 print("A convex FM in cardinality ordering ")
-A = pyw.ShowCoalitionsCard( env)
+A = pyfm.ShowCoalitionsCard( env)
 print( A)
 
-size, v = pyw.generate_fmconvex_tsort( ti, n, n-1 , 1000, 8, 1, env)
+size, v = pyfm.generate_fmconvex_tsort( ti, n, n-1 , 1000, 8, 1, env)
 print( v)
 print("has ", size, " nonzero parameters ")
 
-vb = pyw.ConvertCard2Bit( v, env)
+vb = pyfm.ConvertCard2Bit( v, env)
 
 print("a convex FM in binary ordering ")
-A = pyw.ShowCoalitions( env)
+A = pyfm.ShowCoalitions( env)
 print( A)
 print( vb)
 
-r = pyw.IsMeasureSupermodular( vb, env)
+r = pyfm.IsMeasureSupermodular( vb, env)
 print( "Is it convex (test)?", r)
-r = pyw.IsMeasureAdditive( vb, env)
+r = pyfm.IsMeasureAdditive( vb, env)
 print("Is it additive (test)?", r)
 
-mc = pyw.export_maximal_chains( n, vb, env)
+mc = pyfm.export_maximal_chains( n, vb, env)
 print( "Export maximal chains ")
 print( mc)
 
 x = [0.2,0.1,0.6,0.2]
-z = pyw.Choquet( x, vb, env)
+z = pyfm.Choquet( x, vb, env)
 print( "Choquet integral of ",x, " is ",z)
 
-z = pyw.Sugeno( x, vb, env)
+z = pyfm.Sugeno( x, vb, env)
 print("Sugeno integral of ",x,  " is ",z)
 
 
@@ -60,14 +60,14 @@ print("Sugeno integral of ",x,  " is ",z)
 x = [0.2,0.5,0.4]
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
 kint = 2
-r = pyw.ChoquetKinter( x, v, kint, env)
+r = pyfm.ChoquetKinter( x, v, kint, env)
 print( "Choquet integral of: ", kint, x, v)
 print( "equals: ", r)
 
 # Test wrapper for:
 #    double py_Orness(double* Mob, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-r = pyw.Orness(v, env)
+r = pyfm.Orness(v, env)
 print( "orness value of the Choquet integral wrt fuzzy measure v: ", v)
 print( "equals: ", r)
 
@@ -75,7 +75,7 @@ print( "equals: ", r)
 #    void py_NonmodularityIndexKinteractive(double* v, double* out_w, int kint,  struct fm_env* env)
 kint = 2
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-pnm = pyw.NonmodularityIndexKinteractive( v, kint, env)
+pnm = pyfm.NonmodularityIndexKinteractive( v, kint, env)
 print( "nonmodularity indices of k-interactive fuzzy measure v: ", kint, v)
 print( "equals: ", pnm)
 
@@ -85,7 +85,7 @@ print( "equals: ", pnm)
 x = [0,0.3,0.5,0.6,0.7,0.8,0.85,0.9]
 n = len( x)
 S = 6
-min = pyw.min_subset( x, n, S)
+min = pyfm.min_subset( x, n, S)
 print( "x: ", x)
 print( "n: ", n)
 print( "S: ", S)
@@ -94,11 +94,11 @@ print( "min: ", min)
 
 # Test wrapper for:
 #    double py_max_subset(double* x, int n, int_64 S)
-# pyw.max_subset(x, n, S)
+# pyfm.max_subset(x, n, S)
 x = [0,0.3,0.5,0.6,0.7,0.8,0.85,0.9]
 n = len( x)
 S = 5
-max = pyw.max_subset( x, n, S)
+max = pyfm.max_subset( x, n, S)
 print( "x: ", x)
 print( "n: ", n)
 print( "S: ", S)
@@ -109,7 +109,7 @@ print( "max: ", max)
 x = [0,0.3,0.5]
 n = len( x)
 S = 3
-min = pyw.min_subsetC( x, n, S, env)
+min = pyfm.min_subsetC( x, n, S, env)
 print( "x: ", x)
 print( "n: ", n)
 print( "S: ", S)
@@ -120,7 +120,7 @@ print( "min: ", min)
 x = [0,0.3,0.5]
 n = len( x)
 S = 3
-max = pyw.max_subsetNegC( x, n, S, env)
+max = pyfm.max_subsetNegC( x, n, S, env)
 print( "x: ", x)
 print( "n: ", n)
 print( "S: ", S)
@@ -130,7 +130,7 @@ print( "max: ", max)
 #    int py_SizeArraykinteractive(int n, int k, struct fm_env* env)
 n = 3
 k = 1
-s = pyw.SizeArraykinteractive(n, k, env)
+s = pyfm.SizeArraykinteractive(n, k, env)
 print( "n: ", n)
 print( "k: ", k)
 print( "size: ", s)
@@ -139,7 +139,7 @@ print( "size: ", s)
 #    int py_IsSubsetC(int i, int j, struct fm_env* env)
 i = 2
 j = 1
-s = pyw.IsSubsetC(n, k, env)
+s = pyfm.IsSubsetC(n, k, env)
 print( "i: ", i)
 print( "j: ", j)
 print( "size: ", s)
@@ -148,7 +148,7 @@ print( "size: ", s)
 #    int py_IsElementC(int i, int j, struct fm_env* env)
 i = 2
 j = 1
-s = pyw.IsElementC(n, k, env)
+s = pyfm.IsElementC(n, k, env)
 print( "i: ", i)
 print( "j: ", j)
 print( "size: ", s)
@@ -157,7 +157,7 @@ print( "size: ", s)
 #    void py_ExpandKinteractive2Bit(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize)
 src = [0.0340916, 0.01109779, 0.07918582,0.7,1]
 kint = 1
-dest = pyw.ExpandKinteractive2Bit(src, env, kint)
+dest = pyfm.ExpandKinteractive2Bit(src, env, kint)
 print( "src: ", src)
 print( "kint: ", kint)
 print( "dest: ", dest)
@@ -166,7 +166,7 @@ print( "dest: ", dest)
 #    void py_ExpandKinteractive2Bit_m(double* out_dest, double* src, struct fm_env* env, int kint, int arraysize, double* out_VVC)
 src = [0.0340916, 0.01109779, 0.07918582,0.7,1]
 kint = 1
-dest, VVC = pyw.ExpandKinteractive2Bit_m(src, env, kint)
+dest, VVC = pyfm.ExpandKinteractive2Bit_m(src, env, kint)
 print( "src: ", src)
 print( "kint: ", kint)
 print( "dest: ", dest)
@@ -174,16 +174,16 @@ print( "VVC: ", VVC)
 
 # Test wrapper for:
 #    void py_Shapley(double* v, double* out_x, struct fm_env* env)
-# pyw.Shapley(v, env)
+# pyfm.Shapley(v, env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-x = pyw.Shapley( v, env)
+x = pyfm.Shapley( v, env)
 print( "v: ", v)
 print( "x: ", x)
 
 # Test wrapper for:
 #    void py_Banzhaf(double* v, double* out_B, struct fm_env* env)
 v =[0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-x = pyw.Banzhaf(v, env)
+x = pyfm.Banzhaf(v, env)
 print( "v: ", v)
 print( "x: ", x)
 
@@ -191,7 +191,7 @@ print( "x: ", x)
 # Test wrapper for:
 #    void py_ShapleyMob(double* Mob, double* out_x, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-x = pyw.ShapleyMob( Mob, env)
+x = pyfm.ShapleyMob( Mob, env)
 print( "Mob: ", Mob)
 print( "x: ", x)
 
@@ -199,7 +199,7 @@ print( "x: ", x)
 # Test wrapper for:
 #    void py_BanzhafMob(double* Mob, double* out_B, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-x = pyw.BanzhafMob(Mob, env)
+x = pyfm.BanzhafMob(Mob, env)
 print( "Mob: ", Mob)
 print( "x: ", x)
 
@@ -207,7 +207,7 @@ print( "x: ", x)
 #    double py_ChoquetMob(double* x, double* Mob, struct fm_env* env)
 x =[0.6,0.3,0.8]
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-c = pyw.ChoquetMob(x, Mob, env)
+c = pyfm.ChoquetMob(x, Mob, env)
 print( "Mob: ", Mob)
 print( "x: ", x)
 print( "Choquet integral: ", c )
@@ -215,35 +215,35 @@ print( "Choquet integral: ", c )
 # Test wrapper for:
 #    void py_ConstructLambdaMeasure(double* singletons, double* out_lambdax, double* out_v, struct fm_env* env)
 singletons = [0, 0.3, 0.5]
-lambdax, v = pyw.ConstructLambdaMeasure(singletons, env)
+lambdax, v = pyfm.ConstructLambdaMeasure(singletons, env)
 print( "singletons: ", singletons)
 print( "lambdax, v: ", lambdax, v)
 
 # Test wrapper for:
 #    void py_ConstructLambdaMeasureMob(double* singletons, double* out_lambdax, double* out_Mob, struct fm_env* env)
 singletons = [0, 0.3, 0.5]
-lambdax, Mob = pyw.ConstructLambdaMeasureMob(singletons, env)
+lambdax, Mob = pyfm.ConstructLambdaMeasureMob(singletons, env)
 print( "singletons: ", singletons)
 print( "lambdax, Mob: ", lambdax, Mob)
 
 # Test wrapper for:
 #    void py_dualm(double* v, double* out_w, struct fm_env* env)
 v =[0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-w = pyw.dualm(v, env)
+w = pyfm.dualm(v, env)
 print( "v: ", v)
 print( "w: ", w)
 
 # Test wrapper for:
 #    void py_dualmMob(double* v, double* out_w, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-w = pyw.dualmMob(Mob, env)
+w = pyfm.dualmMob(Mob, env)
 print( "Mob: ", Mob)
 print( "w: ", w)
 
 # Test wrapper for:
 #    double py_Entropy(double* v, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-r = pyw.Entropy(v, env)
+r = pyfm.Entropy(v, env)
 print( "v: ", v)
 print( "r: ", r)
 
@@ -251,7 +251,7 @@ print( "r: ", r)
 #    void py_FuzzyMeasureFit(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 2
-res, dataset = pyw.FuzzyMeasureFit(datanum, additive, env, dataset = None)
+res, dataset = pyfm.FuzzyMeasureFit(datanum, additive, env, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -261,7 +261,7 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitMob(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 3
-res, dataset = pyw.FuzzyMeasureFitMob(datanum, additive, env, dataset = None)
+res, dataset = pyfm.FuzzyMeasureFitMob(datanum, additive, env, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -271,7 +271,7 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitKtolerant(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 2
-res, dataset = pyw.FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None)
+res, dataset = pyfm.FuzzyMeasureFitKtolerant(datanum, additive, env, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -281,7 +281,7 @@ print( "res: ", res)
 #    void py_FuzzyMeasureFitLPKmaxitive(int datanum, int additive, struct fm_env* env, double* out_v, double* dataset)
 datanum = 10
 additive = 2
-res, dataset = pyw.FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None)
+res, dataset = pyfm.FuzzyMeasureFitLPKmaxitive(datanum, additive, env, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "dataset: ", dataset)
@@ -292,7 +292,7 @@ print( "res: ", res)
 datanum = 10
 additive = 2
 K = 0.5
-v, dataset = pyw.FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None)
+v, dataset = pyfm.FuzzyMeasureFitLPKinteractive(datanum, additive, env, K, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "K: ", K)
@@ -305,7 +305,7 @@ print( "v: ", v)
 datanum = 10
 additive = 2
 K = 0.5
-v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None)
+v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveMaxChains(datanum, additive, env, K, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "K: ", K)
@@ -318,7 +318,7 @@ datanum = 10
 additive = 2
 K = 0.5
 maxiters = [100]
-v, dataset = pyw.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None)
+v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveAutoK(datanum, additive, env, K, maxiters, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "K: ", K)
@@ -332,7 +332,7 @@ datanum = 10
 additive = 2
 K = 0.5
 submod = 1
-v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset = None)
+v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveMarginal(datanum, additive, env,  K, submod, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "submod: ", submod)
@@ -346,7 +346,7 @@ datanum = 10
 additive = 2
 K = 0.5
 submod = 1
-v, dataset = pyw.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None)
+v, dataset = pyfm.FuzzyMeasureFitLPKinteractiveMarginalMaxChain(datanum, additive, env, K, maxiters, submod, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "submod: ", submod)
@@ -363,7 +363,7 @@ indexlow = [0, 0, 0]
 indexhihg = [1, 1, 1]
 option1 = [0]
 orness = [0.5]
-v, dataset = pyw.FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
+v, dataset = pyfm.FuzzyMeasureFitLP(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "indexlow: ", indexlow)
@@ -383,7 +383,7 @@ indexlow = [0, 0, 0]
 indexhihg = [1, 1, 1]
 option1 = [0]
 orness = [0.5]
-Mob, dataset = pyw.FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
+Mob, dataset = pyfm.FuzzyMeasureFitLPMob(datanum, additive, env, options, indexlow, indexhihg, option1, orness, dataset = None)
 print( "datanum: ", datanum)
 print( "additive: ", additive)
 print( "indexlow: ", indexlow)
@@ -398,7 +398,7 @@ print( "Mob: ", Mob)
 #    void py_fittingOWA(int datanum, struct fm_env* env, double* out_v, double* dataset)
 # documented, no example
 datanum = 10
-v , dataset = pyw.fittingOWA(datanum, env, dataset = None)
+v , dataset = pyfm.fittingOWA(datanum, env, dataset = None)
 print( "datanum: ", datanum)
 print( "dataset: ", dataset)
 print( "v: ", v)
@@ -408,42 +408,42 @@ print( "v: ", v)
 # documented, no example
 datanum = 10
 atanum = 10
-v , dataset = pyw.fittingWAM(datanum, env, dataset = None)
+v , dataset = pyfm.fittingWAM(datanum, env, dataset = None)
 print( "datanum: ", datanum)
 print( "dataset: ", dataset)
 print( "v: ", v)
 
 
 
-pyw.fm_free( env)
+pyfm.fm_free( env)
 n = 3
-env = pyw.fm_init( n)
+env = pyfm.fm_init( n)
 
 # Test wrapper for:
 #    void py_Interaction(double* Mob, double* out_v, struct fm_env* env)
 Mob = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-v = pyw.Interaction(Mob, env)
+v = pyfm.Interaction(Mob, env)
 print( "Mob: ", Mob)
 print( "v: ", v)
 
 # Test wrapper for:
 #    void py_InteractionB(double* Mob, double* out_v, struct fm_env* env)
 Mob = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-v = pyw.InteractionB(Mob, env)
+v = pyfm.InteractionB(Mob, env)
 print( "Mob: ", Mob)
 print( "v: ", v)
 
 # Test wrapper for:
 #    void py_InteractionMob(double* Mob, double* out_v, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-v = pyw.InteractionMob(Mob, env)
+v = pyfm.InteractionMob(Mob, env)
 print( "Mob: ", Mob)
 print( "v: ", v)
 
 # Test wrapper for:
 #    void py_InteractionBMob(double* Mob, double* out_v, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-v = pyw.InteractionBMob(Mob, env)
+v = pyfm.InteractionBMob(Mob, env)
 print( "Mob: ", Mob)
 print( "v: ", v)
 
@@ -452,7 +452,7 @@ print( "v: ", v)
 #    void py_BipartitionShapleyIndex(double* v, double* out_w, struct fm_env* env)
 # not documented in R or Python user guide
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
-s = pyw.BipartitionShapleyIndex(v, env)
+s = pyfm.BipartitionShapleyIndex(v, env)
 print( "v: ", v)
 print( "s: ", s)
 
@@ -460,7 +460,7 @@ print( "s: ", s)
 #    void py_BipartitionBanzhafIndex(double* v, double* out_w, struct fm_env* env)
 # not documented in R or Python user guide
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
-s = pyw.BipartitionBanzhafIndex(v, env)
+s = pyfm.BipartitionBanzhafIndex(v, env)
 print( "v: ", v)
 print( "s: ", s)
 
@@ -468,28 +468,28 @@ print( "s: ", s)
 #    void py_BNonadditivityIndexMob(double* Mob, double* out_w, struct fm_env* env)
 # not documented in R or Python user guide
 Mob = [0.2, 0.3, 0.5, -0.2, 0.4, 0.1]
-s = pyw.BNonadditivityIndexMob(Mob, env)
+s = pyfm.BNonadditivityIndexMob(Mob, env)
 print( "v: ", v)
 print( "s: ", s)
 
 # Test wrapper for:
 #    void py_NonadditivityIndex(double* v, double* out_w, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-w = pyw.NonadditivityIndex(v, env)
+w = pyfm.NonadditivityIndex(v, env)
 print( "v: ", v)
 print( "w: ", w)
 
 # Test wrapper for:
 #    void py_NonmodularityIndex(double* v, double* out_w, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-w = pyw.NonmodularityIndex(v, env)
+w = pyfm.NonmodularityIndex(v, env)
 print( "v: ", v)
 print( "w: ", w)
 
 # Test wrapper for:
 #    void py_NonmodularityIndexMob(double* Mob, double* out_w, struct fm_env* env)
 v =[0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-w = pyw.NonmodularityIndexMob(v, env)
+w = pyfm.NonmodularityIndexMob(v, env)
 print( "v: ", v)
 print( "w: ", w)
 
@@ -497,7 +497,7 @@ print( "w: ", w)
 #    void py_NonmodularityIndexMobkadditive(double* Mob, double* out_w, int k,  struct fm_env* env)
 k = 2
 Mob =[0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-pnm = pyw.NonmodularityIndexMobkadditive(Mob, k, env)
+pnm = pyfm.NonmodularityIndexMobkadditive(Mob, k, env)
 print( "k: ", k)
 print( "Mob: ", Mob)
 print( "nonmodularity indices: ", pnm)
@@ -505,42 +505,42 @@ print( "nonmodularity indices: ", pnm)
 # Test wrapper for:
 #    int py_IsMeasureBalanced(double* v, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-is_measure = pyw.IsMeasureBalanced(v, env)
+is_measure = pyfm.IsMeasureBalanced(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSelfdual(double* v, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-is_measure = pyw.IsMeasureSelfdual(v, env)
+is_measure = pyfm.IsMeasureSelfdual(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSubadditive(double* v, struct fm_env* env)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-is_measure = pyw.IsMeasureSubadditive(v, env)
+is_measure = pyfm.IsMeasureSubadditive(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSubmodular(double* v, struct fm_env* env)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-is_measure = pyw.IsMeasureSubmodular(v, env)
+is_measure = pyfm.IsMeasureSubmodular(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSuperadditive(double* v, struct fm_env* env)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-is_measure = pyw.IsMeasureSuperadditive(v, env)
+is_measure = pyfm.IsMeasureSuperadditive(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSymmetric(double* v, struct fm_env* env)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-is_measure = pyw.IsMeasureSymmetric(v, env)
+is_measure = pyfm.IsMeasureSymmetric(v, env)
 
 print( "v: ", v)
 print( "is_measure: ", is_measure)
@@ -548,21 +548,21 @@ print( "is_measure: ", is_measure)
 # Test wrapper for:
 #    int py_IsMeasureKMaxitive(double* v, struct fm_env* env)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1, -0.2, 0.1]
-is_measure = pyw.IsMeasureKMaxitive(v, env)
+is_measure = pyfm.IsMeasureKMaxitive(v, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureAdditiveMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureAdditiveMob(Mob, env)
+is_measure = pyfm.IsMeasureAdditiveMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureBalancedMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureBalancedMob(Mob, env)
+is_measure = pyfm.IsMeasureBalancedMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
@@ -570,56 +570,56 @@ print( "is_measure: ", is_measure)
 # Test wrapper for:
 #    int py_IsMeasureSelfdualMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureSelfdualMob(Mob, env)
+is_measure = pyfm.IsMeasureSelfdualMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSubadditiveMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureSubadditiveMob(Mob, env)
+is_measure = pyfm.IsMeasureSubadditiveMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSubmodularMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureSubmodularMob(Mob, env)
+is_measure = pyfm.IsMeasureSubmodularMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSuperadditiveMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureSuperadditiveMob(Mob, env)
+is_measure = pyfm.IsMeasureSuperadditiveMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSupermodularMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureSupermodularMob(Mob, env)
+is_measure = pyfm.IsMeasureSupermodularMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureSymmetricMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureSymmetricMob(Mob, env)
+is_measure = pyfm.IsMeasureSymmetricMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    int py_IsMeasureKMaxitiveMob(double* Mob, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-is_measure = pyw.IsMeasureKMaxitiveMob(Mob, env)
+is_measure = pyfm.IsMeasureKMaxitiveMob(Mob, env)
 print( "v: ", v)
 print( "is_measure: ", is_measure)
 
 # Test wrapper for:
 #    void py_Mobius(double* v, double* out_MobVal, struct fm_env* env)
 v = [0,0.3,0.5,0.6,0.4,0.8,0.7,1]
-Mob = pyw.Mobius(v, env)
+Mob = pyfm.Mobius(v, env)
 print( "v: ", v)
 print( "Mob: ", Mob)
 
@@ -628,7 +628,7 @@ print( "Mob: ", Mob)
 # not documented in R or Python user guide
 x = [0.3, 0.4, 0.8, 0.2]   # inputs
 w = [0.4, 0.35 ,0.2 ,0.05] # OWA weights
-res = pyw.OWA(x, v, env)
+res = pyfm.OWA(x, v, env)
 print( "v: ", v)
 print( "w: ", w)
 print( "res: ", res)
@@ -638,7 +638,7 @@ print( "res: ", res)
 # not documented in R or Python user guide
 x = [0.3, 0.4, 0.8, 0.2]   # inputs
 w = [0.4, 0.35 ,0.2 ,0.05] # OWA weights
-res = pyw.WAM(x, v, env)
+res = pyfm.WAM(x, v, env)
 print( "v: ", v)
 print( "w: ", w)
 print( "res: ", res)
@@ -646,7 +646,7 @@ print( "res: ", res)
 # Test wrapper for:
 #    void py_Zeta(double* Mob, double* out_v, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
-v = pyw.Zeta(Mob, env)
+v = pyfm.Zeta(Mob, env)
 print( "Mob: ", Mob)
 print( "v: ", v)
 
@@ -654,7 +654,7 @@ print( "v: ", v)
 #    void py_dualMobKadd(int k, double* src, double* out_dest, struct fm_env* env)
 Mob = [0.0,0.3,0.5,-0.2,0.4,0.1,-0.2,0.1]
 kadd = 2
-dual, length = pyw.dualMobKadd(kadd, Mob, env)
+dual, length = pyfm.dualMobKadd(kadd, Mob, env)
 print( "Mob: ", Mob)
 print( "kadd: ", kadd)
 print( "length of output: ", length)
@@ -664,7 +664,7 @@ print( "dual: ", dual)
 #    void py_Shapley2addMob(double* v, double* out_x, int n)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
 n = len( v)
-shapley = pyw.Shapley2addMob( v, n)
+shapley = pyfm.Shapley2addMob( v, n)
 print( "v: ", v)
 print( "n: ", n)
 print( "shapley: ", shapley)
@@ -673,7 +673,7 @@ print( "shapley: ", shapley)
 #    void py_Banzhaf2addMob(double* v, double* out_x, int n)
 v = [0.0, 0.3, 0.5, -0.2, 0.4, 0.1]
 n = len(v)
-banzhaf = pyw.Banzhaf2addMob(v, n)
+banzhaf = pyfm.Banzhaf2addMob(v, n)
 print( "v: ", v)
 print( "n: ", n)
 print( "banzhaf: ", banzhaf)
@@ -683,7 +683,7 @@ print( "banzhaf: ", banzhaf)
 x =[0.2,0.5,0.4]
 Mob = [0.2, 0.3, 0.5, -0.2, 0.4, 0.1]
 n = len( Mob)
-ci = pyw.Choquet2addMob(x, Mob, n)
+ci = pyfm.Choquet2addMob(x, Mob, n)
 print( "x: ", x)
 print( "Mob: ", Mob)
 print( "CI: ", ci)
@@ -692,14 +692,14 @@ print( "CI: ", ci)
 #    int py_fm_arraysize(int n, int kint, struct fm_env* env)
 kint = 2
 n = env.n
-l = pyw.fm_arraysize(n, kint, env)
+l = pyfm.fm_arraysize(n, kint, env)
 print( "kint: ", kint)
 print( "n: ", n)
 print( "length: ", l)
 
 # Test wrapper for:
 #    int py_generate_fm_minplus(int num, int n, int kint, int markov, int option, double K, double* out_vv, struct fm_env* env)
-# pyw.generate_fm_minplus(num, n, kint, markov, option, K, out_vv, env)
+# pyfm.generate_fm_minplus(num, n, kint, markov, option, K, out_vv, env)
 # not documented in R or Python user guide
 num = 10
 n = 6
@@ -710,7 +710,7 @@ K = 0.7
 ret_code = 0
 length = 0
 vv = []
-ret_code, vv, length = pyw.generate_fm_minplus(num, n, kint, markov, option, K, env)
+ret_code, vv, length = pyfm.generate_fm_minplus(num, n, kint, markov, option, K, env)
 print( "num: ", num)
 print( "n: ", n)
 print( "kint: ", kint)
@@ -728,7 +728,7 @@ num = 10
 n = 6
 ret_code = 0
 length = 0
-ret_code, vv, length = pyw.generate_fm_2additive_convex(num, n)
+ret_code, vv, length = pyfm.generate_fm_2additive_convex(num, n)
 print( "num: ", num)
 print( "n: ", n)
 print( "ret_code: ", ret_code)
@@ -743,16 +743,16 @@ num = 10
 n = 6
 ret_code = 0
 length = 0
-ret_code, vv, length = pyw.generate_fm_2additive_convex_withsomeindependent(num, n)
+ret_code, vv, length = pyfm.generate_fm_2additive_convex_withsomeindependent(num, n)
 print( "num: ", num)
 print( "n: ", n)
 print( "ret_code: ", ret_code)
 print( "length of output: ", length)
 print( "vv: ", vv)
 
-pyw.fm_free( env);
+pyfm.fm_free( env);
 n = 3
-env = pyw.fm_init( n)
+env = pyfm.fm_init( n)
 
 #
 # --- Here the testing for env_sparse, n = 3 starts ---
@@ -762,26 +762,26 @@ env = pyw.fm_init( n)
 #    void py_prepare_fm_sparse(int n, int tupsize, int* tuples, struct fm_env_sparse* out_env)
 n = 3
 tupsize = 0
-env_sparse = pyw.prepare_fm_sparse( n, tupsize)
+env_sparse = pyfm.prepare_fm_sparse( n, tupsize)
 
 # Test wrapper for:
 #    void py_add_tuple_sparse(int tupsize, int* tuple, double v, struct fm_env_sparse* env)
 v = 0.2
 tuple = [1, 3, 4]
-pyw.add_tuple_sparse( tuple, v, env_sparse)
+pyfm.add_tuple_sparse( tuple, v, env_sparse)
 print( "tuple: ", tuple)
 
 # Test wrapper for:
 #    void py_ShapleyMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
 n = 3
-v = pyw.ShapleyMob_sparse(n, env_sparse)
+v = pyfm.ShapleyMob_sparse(n, env_sparse)
 print( "n: ", n)
 print( "Shapley values: ", v)
 
 # Test wrapper for:
 #    void py_BanzhafMob_sparse(double* out_v, int n, struct fm_env_sparse* env)
 n = 3
-v = pyw.BanzhafMob_sparse(n, env_sparse)
+v = pyfm.BanzhafMob_sparse(n, env_sparse)
 print( "n: ", n)
 print( "Banzhaf values: ", v)
 
@@ -790,7 +790,7 @@ print( "Banzhaf values: ", v)
 v = 0.2
 i = 2
 j = 5
-pyw.add_pair_sparse(i, j, v, env_sparse)
+pyfm.add_pair_sparse(i, j, v, env_sparse)
 print( "v: ", v)
 print( "i: ", i)
 print( "j: ", j)
@@ -799,10 +799,10 @@ print( "j: ", j)
 # Test wrapper for:
 #    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)
 n = 3
-yy, v, length = pyw.generate_fm_2additive_convex_withsomeindependent( 1, n) 
+yy, v, length = pyfm.generate_fm_2additive_convex_withsomeindependent( 1, n) 
 print( "n: ", n)
 print( "v: ", v)
-pyw.populate_fm_2add_sparse_from2add( n, v, env_sparse)
+pyfm.populate_fm_2add_sparse_from2add( n, v, env_sparse)
 
 # Test wrapper for:
 #    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)
@@ -811,7 +811,7 @@ singletons = [0.1,0.2,0.3]
 pairs = [0.4,0.5,0.6]
 indicesp1 = [1,1,2]
 indicesp2 = [2,3,3]
-pyw.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env_sparse)
+pyfm.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env_sparse)
 print( "numpairs: ", numpairs)
 print( "singletons: ", singletons)
 print( "pairs: ", pairs)
@@ -821,55 +821,53 @@ print( "indicesp2: ", indicesp2)
 # Test wrapper for:
 #    void py_expand_2add_full(double* out_v, struct fm_env_sparse* env)
 n = 3
-v = pyw.expand_2add_full( n, env_sparse)
+v = pyfm.expand_2add_full( n, env_sparse)
 print( "n: ", n)
 print( "v: ", v)
 
 # Test wrapper for:
 #    void py_sparse_get_singletons(int n, double* out_v, struct fm_env_sparse* env)
 n = 3
-v = pyw.sparse_get_singletons(n, env_sparse)
+v = pyfm.sparse_get_singletons(n, env_sparse)
 print( "n: ", n)
 print( "singletons: ", v)
 
 # Test wrapper for:
 #    int py_sparse_get_pairs(int* pairs, double* v, struct fm_env_sparse* env)
 n = 3
-pairs, v = pyw.sparse_get_pairs( n, env_sparse)
+pairs, v = pyfm.sparse_get_pairs( n, env_sparse)
 print( "n: ", n)
 print( "pairs: ", pairs)
 print( "v: ", v)
 
 # Test wrapper for:
 #    int py_sparse_get_tuples(int* tuples, double* v, struct fm_env_sparse* env)
-tuples, v = pyw.sparse_get_tuples( env_sparse)
+tuples, v = pyfm.sparse_get_tuples( env_sparse)
 print( "tuples: ", tuples)
 print( "v: ", v)
 
-sys.exit()
-
 # Test wrapper for:
 #    void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)
 n =3
-w = pyw.Nonmodularityindex_sparse(n, env_sparse)
+w = pyfm.Nonmodularityindex_sparse(n, env_sparse)
 print( "n: ", n)
 print( "w: ", w)
 
 # Test wrapper for:
 #    int py_tuple_cardinality_sparse(int i, struct fm_env_sparse* env)
 i = 0;
-tup_card = pyw.tuple_cardinality_sparse(i, env_sparse)
+tup_card = pyfm.tuple_cardinality_sparse(i, env_sparse)
 print( "i: ", i)
 print( "tup_card: ", tup_card)
 
 # Test wrapper for:
 #    int py_get_num_tuples(struct fm_env_sparse* env)
-num_tup = pyw.get_num_tuples(env_sparse)
+num_tup = pyfm.get_num_tuples(env_sparse)
 print( "num_tup: ", num_tup)
 
 # Test wrapper for:
 #    int py_get_sizearray_tuples(struct fm_env_sparse* env)
-length = pyw.get_sizearray_tuples(env_sparse)
+length = pyfm.get_sizearray_tuples(env_sparse)
 print( "length of array of tuples: ", length)
 
 # Test wrapper for:
@@ -877,7 +875,7 @@ print( "length of array of tuples: ", length)
 A = 0
 card = 3
 i = 1
-is_contained = pyw.is_inset_sparse(A, card, i, env_sparse)
+is_contained = pyfm.is_inset_sparse(A, card, i, env_sparse)
 print( "A: ", A)
 print( "card: ", card)
 print( "i: ", i)
@@ -889,7 +887,7 @@ A = 0
 cardA = 3
 B = 1
 cardB = 3
-is_subset = pyw.is_subset_sparse(A, cardA, B, cardB, env_sparse)
+is_subset = pyfm.is_subset_sparse(A, cardA, B, cardB, env_sparse)
 print( "A: ", A)
 print( "cardA: ", cardA)
 print( "B: ", B)
@@ -902,7 +900,7 @@ x = [0.1,0.05,0.2]
 n = 3
 S = 0
 cardS = 3
-yy = pyw.min_subset_sparse(x, n, S, cardS, env_sparse)
+yy = pyfm.min_subset_sparse(x, n, S, cardS, env_sparse)
 print( "x: ", x)
 print( "n: ", n)
 print( "S: ", S)
@@ -915,7 +913,7 @@ x = [0.1,0.05,0.2]
 n = 3
 S = 0
 cardS = 3
-yy =pyw.max_subset_sparse(x, n, S, cardS, env_sparse)
+yy =pyfm.max_subset_sparse(x, n, S, cardS, env_sparse)
 print( "x: ", x)
 print( "n: ", n)
 print( "S: ", S)
@@ -925,24 +923,24 @@ print( "yy: ", yy)
 # Test wrapper for:
 #    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
 x = [0.1,0.05,0.2]
-c_i = pyw.ChoquetMob_sparse(x, env_sparse)
+c_i = pyfm.ChoquetMob_sparse(x, env_sparse)
 print( "x: ", x)
 print( "Choquet integral: ", c_i)
 
 # Test wrapper for:
 #    void py_free_fm_sparse( struct fm_env_sparse* env)
-pyw.free_fm_sparse( env_sparse)
+pyfm.free_fm_sparse( env_sparse)
 
 #
 # --- new env sparse for n = 5 ---
 #
 n = 5
 tupsize = 0
-env_sparse = pyw.prepare_fm_sparse( n, tupsize)
+env_sparse = pyfm.prepare_fm_sparse( n, tupsize)
 
 # Test wrapper for:
 #    int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)
-yy = pyw.generate_fm_2additive_convex_sparse(n, env_sparse)
+yy = pyfm.generate_fm_2additive_convex_sparse(n, env_sparse)
 print( "n: ", n)
 print( "yy: ", yy)
 
@@ -950,7 +948,7 @@ print( "yy: ", yy)
 #    int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)
 k = 4
 nonzero = 10
-yy = pyw.generate_fm_kadditive_convex_sparse(n, k, nonzero, env_sparse)
+yy = pyfm.generate_fm_kadditive_convex_sparse(n, k, nonzero, env_sparse)
 print( "n: ", n)
 print( "k: ", k)
 print( "nonzero: ", nonzero)
@@ -959,7 +957,7 @@ print( "yy: ", yy)
 #
 # --- free env sparse for n = 5 ---
 #
-pyw.free_fm_sparse( env_sparse)
+pyfm.free_fm_sparse( env_sparse)
 
 
 
